const router = require('express').Router();
const User = require('../models/User');
const auth = require("../middleware/auth");

router.post('/', async (req, res) => {
    try {
        const user = new User({
            username: req.body.username,
            password: req.body.password
        });

        user.generateToken();
        await user.save();

        res.send(user);
    } catch (e) {
        res.status(400).send(e);
    }
});

router.put('/', auth, async (req, res) => {
    const user = req.user;

    if (
        req.body.oldPassword.trim()
        &&
        !await user.checkPassword(req.body.oldPassword.toString())
    ) {
        return res
            .status(400)
            .send({error: 'Old password incorrect'});
    }

    try {
        user.password = req.body.password || user.password;
        user.username = req.body.username || user.username;
        await user.save();

        res.send(user);
    } catch (e) {
        res
            .status(400)
            .send({error: e.message});
    }
});

router.post('/login', async (req, res) => {
    const user = await User.findOne({username: req.body.username});

    if (!user) return res
        .status(400)
        .send({error: 'Username or password incorrect'});

    if (!await user.checkPassword(req.body.password.toString())) return res
        .status(400)
        .send({error: 'Username or password incorrect'});

    try {
        user.generateToken();
        await user.save();

        res.send(user);
    } catch (e) {
        res
            .status(400)
            .send({error: e.message});
    }
});

router.get('/profile', auth, async (req, res) => {
    res.send(req.user);
});

router.delete('/logout', auth, async (req, res) => {
    req.user.token = null;
    req.user.save();

    res.send({message: 'Success'});
});

module.exports = router;
